Returns image pointed to by link, or nil if link is not a valid image link.
Parameters:
Returns:
image pointed to by link, or nil if link is not a valid image link
77
# File 'lib/spotify/api/image.rb', line 77 attach_function :image_create_from_link, [ Session, Link ], Image