Class: Spotify::Session

Inherits:
ManagedPointer show all
Defined in:
lib/spotify/types/session.rb

Overview

Session pointers are special in that they are created once, never increases or decreases in reference count and should never be released.

See the ManagedPointer for documentation.

Instance Method Summary collapse

Methods inherited from ManagedPointer

#free, from_native, #inspect, release, retain, retaining_class, size, to_native, type, #type

Methods included from TypeSafety

#to_native, #type_class

Constructor Details

#initializeSession

After initialization sets autorelease to false.



15
16
17
18
# File 'lib/spotify/types/session.rb', line 15

def initialize(*)
  super
  self.autorelease = false
end